summaryrefslogtreecommitdiff
path: root/src/HTML5/Parser/CharacterReference.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/HTML5/Parser/CharacterReference.php')
-rw-r--r--src/HTML5/Parser/CharacterReference.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/HTML5/Parser/CharacterReference.php b/src/HTML5/Parser/CharacterReference.php
index 526a8b1..2ead49e 100644
--- a/src/HTML5/Parser/CharacterReference.php
+++ b/src/HTML5/Parser/CharacterReference.php
@@ -1,13 +1,13 @@
<?php
-namespace HTML5\Parser;
+namespace Masterminds\HTML5\Parser;
-use \HTML5\Entities;
+use Masterminds\HTML5\Entities;
/**
* Manage entity references.
*
* This is a simple resolver for HTML5 character reference entitites.
* See \HTML5\Entities for the list of supported entities.
*/
class CharacterReference {
@@ -1,13 +1,13 @@
*
* This is a simple resolver for HTML5 character reference entitites.
- * See \HTML5\Entities for the list of supported entities.
+ * See \Masterminds\HTML5\Entities for the list of supported entities.
*/
class CharacterReference {